---
name: Feature request
about: Suggest a new feature for SCALib
title: ''
labels: ''
assignees: ''

---

**What is the problem you would like to solve? Please describe.**
A clear and concise description of what the problem is. Give context.

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**References and state of the art**
Is there any relevant literature related to the problem or to the proposed solutions? Any implementation of the technique or of a similar algorithm?

**SCALib's scope (Please remove this section after reading it.)**

SCALib is a library for practitioners and researchers in the field of side-channel security evaluations. Our goal is to collect high-quality implementations of generally useful algorithms for this purpose. Here are a few guidelines we follow:

- Be state-of-the-art, but not a research project: implementation of new techniques are welcome, but they should be proven (having been published or used in a practical setting is generally required).
- Don't implement every possible algorithm: we avoid very niche or outdated algorithms.
- Algorithms for evaluation, not attack. E.g., we have a key rank estimation algorithm, but no key enumeration (until someone makes a convincing case that key rank estimation is not sufficient in an evaluation context).
